"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[179],{47626:function(o,n,i){i.r(n);var s=i(72791),t=i(57678),e=i(40584),l=i(80184);n.default=function(o){var n=(o.options.options||[]).map((function(o){return{value:"".concat(o),label:"".concat(o)}})),i=s.useMemo((function(){return"".concat(o.options.isMulti?"multi_":"","select_").concat((0,e.Z)())}),[o.options.isMulti]);return(0,l.jsxs)(t.xu,{display:"flex",fd:"column",children:[o.options.label&&(0,l.jsx)(t.xv,{as:"label",htmlFor:i,lineHeight:1.5,disabled:o.options.disabled,children:o.options.label}),(0,l.jsx)(t.Ph,{multiple:o.options.isMulti,searchable:o.options.searchable,disabled:o.options.disabled,value:o.options.value,popoverProps:{align:"start"},triggerProps:{css:{width:"unset"}},options:[{group:"",options:n}],onValueChange:function(n){var i;"function"===typeof(null===(i=o.callbacks)||void 0===i?void 0:i.on_change)&&o.callbacks.on_change(n)}},i)]})}}}]);
//# sourceMappingURL=Select.50f25010.chunk.js.map