"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[8537],{75616:function(a,t,n){var e=n(93433),o=n(72791),r=n(67571),c=n(94266),i=n(43403),p=n(55779),u=n(16729),s=n(7779),d=n(49379);t.Z=function(){var a,t=(0,r.k6)(),n=(0,r.TH)(),l=(0,u.Z)((function(a){return a.isLoading})),f=(0,u.Z)((function(a){return a.editBoard})),h=(0,u.Z)((function(a){return a.fetchBoard})),v=(0,u.Z)((function(a){return a.boards})),m=(0,u.Z)((function(a){return a.notifyData})),g=(0,u.Z)((function(a){return a.appName})),k=(0,u.Z)((function(a){return a.setAppName})),x=(0,s.w)(s.Z.boardsSelector),Z=g&&null!==(a=null===x||void 0===x?void 0:x[g])&&void 0!==a?a:[],y=o.useMemo((function(){var a=c.Z(Z),t=a.filter((function(a){return a.includes("/")})),n=a.filter((function(a){return!a.includes("/")}));return[].concat((0,e.Z)(t),(0,e.Z)(n))}),[Z]);return o.useEffect((function(){d.t(i.q.app.pageView)}),[]),o.useEffect((function(){if(!l&&g&&y.length>0&&n.pathname===p.A.App.replace(":appName",g)){var a=y[0];t.replace("".concat(p.A.App.replace(":appName",g),"/").concat(a))}}),[Z,n,g]),{data:y,updateBoard:f,boards:v,isLoading:l,fetchBoard:h,notifications:m,appName:g,setAppName:k}}},40500:function(a,t,n){n.r(t),n.d(t,{default:function(){return s}});n(72791);var e=n(7469),o=(0,e.Z)("layout-2","IconLayout2",[["path",{d:"M4 4m0 2a2 2 0 0 1 2 -2h2a2 2 0 0 1 2 2v1a2 2 0 0 1 -2 2h-2a2 2 0 0 1 -2 -2z",key:"svg-0"}],["path",{d:"M4 13m0 2a2 2 0 0 1 2 -2h2a2 2 0 0 1 2 2v3a2 2 0 0 1 -2 2h-2a2 2 0 0 1 -2 -2z",key:"svg-1"}],["path",{d:"M14 4m0 2a2 2 0 0 1 2 -2h2a2 2 0 0 1 2 2v3a2 2 0 0 1 -2 2h-2a2 2 0 0 1 -2 -2z",key:"svg-2"}],["path",{d:"M14 15m0 2a2 2 0 0 1 2 -2h2a2 2 0 0 1 2 2v1a2 2 0 0 1 -2 2h-2a2 2 0 0 1 -2 -2z",key:"svg-3"}]]),r=(0,e.Z)("external-link","IconExternalLink",[["path",{d:"M11 7h-5a2 2 0 0 0 -2 2v9a2 2 0 0 0 2 2h9a2 2 0 0 0 2 -2v-5",key:"svg-0"}],["path",{d:"M10 14l10 -10",key:"svg-1"}],["path",{d:"M15 4l5 0l0 5",key:"svg-2"}]]),c=n(57678),i=n(55779),p=n(75616),u=n(80184);var s=function(a){var t=(0,p.Z)(),n=t.data,e=t.appName,s=new URL(window.location.href),d=s.pathname.startsWith(i.A.Apps)&&s.pathname.endsWith("/edit"),l=a.options.package_name,f=a.options.state_param,h=a.data.indexOf(":"),v=(-1===h?null:a.data.slice(0,h))?a.data:l&&!n.includes(a.data)?"".concat(l,":").concat(a.data):a.data;return(0,u.jsx)(c.rU,{css:{display:"flex",color:"$textPrimary",textDecoration:"underline",textDecorationColor:"$textPrimary50"},to:"".concat(i.A.App.replace(":appName",e),"/").concat(v).concat(d?"/edit":"").concat(f?"?state="+f:""),target:a.options.new_tab?"_blank":void 0,children:(0,u.jsx)(c.zx,{leftIcon:(0,u.jsx)(o,{color:"#45484D"}),rightIcon:a.options.new_tab&&(0,u.jsx)(r,{color:"#45484D"}),horizontalSpacing:"compact",size:"md",variant:"ghost",color:"secondary",children:(0,u.jsx)(c.xv,{children:a.options.text})})})}}}]);
//# sourceMappingURL=BoardLink.092d667d.chunk.js.map