"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[5443],{48520:function(e,n,u){u.r(n);var a=u(1413),i=u(29439),s=u(72791),c=u(57678),l=u(40584),o=u(80184);function t(e){var n=s.useState(e.options.value),u=(0,i.Z)(n,2),t=u[0],r=u[1];s.useEffect((function(){e.options.value!==t&&r(e.options.value)}),[e.options.value]);var f=s.useCallback((function(n){var u;r(n),null===(u=e.callbacks)||void 0===u||u.on_change(n)}),[]),h=s.useMemo(l.Z,[]);return(0,o.jsx)(c.xu,{children:(0,o.jsx)(c.xu,{display:"flex",ai:"center",children:(0,o.jsx)(c.XZ,(0,a.Z)((0,a.Z)({},e.options),{},{id:h,checked:t,onCheckedChange:f}))})})}t.displayName="CheckboxVizElement",n.default=t}}]);
//# sourceMappingURL=Checkbox.7aeee8d5.chunk.js.map