"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[6523],{54501:function(e,t,n){n.r(t),n.d(t,{default:function(){return f}});var r=n(72791),i=n(4942),o=n(29439),u=n(1413),c=n(34709),l=n.n(c),s=n(40674),h=n(74891),d=n(80184),a=function(e){var t,n=e.data,c=function(e){return(0,d.jsx)(s.Rect,(0,u.Z)({fill:"#1473e6",draggable:!0,hitStrokeWidth:20,onMouseEnter:function(){return document.body.style.cursor="ew-resize"},onMouseLeave:function(){return document.body.style.cursor="default"},dragBoundFunc:function(e){return(0,u.Z)((0,u.Z)({},e),{},{y:0})}},e))},a=function(e){e.rowIndex;var t=e.columnIndex,r=e.x,i=e.y,o=e.width,u=e.height,l=e.onResize,h=Object.keys(n[0])[t];return(0,d.jsxs)(s.Group,{children:[(0,d.jsx)(s.Rect,{x:r,y:i,height:u,width:o,fill:"#eee",stroke:"grey",strokeWidth:.5}),(0,d.jsx)(s.Text,{x:r,y:i,height:u,width:o,text:h,fontStyle:"bold",verticalAlign:"middle",align:"center"}),(0,d.jsx)(c,{x:r+o-2,y:i,width:2,height:u,onDragMove:function(e){var n=e.target.x()-r+2;l(t,n)}})]})},f=Object.keys(null!==(t=n[0])&&void 0!==t?t:{}).length,x=n.length,g=(0,r.useRef)(),y=(0,r.useRef)(),w=(0,h.Z)(),m=(0,o.Z)(w,2),j=m[0],v=m[1],k=v.width,b=v.height,Z=(0,r.useState)({}),R=(0,o.Z)(Z,2),C=R[0],p=R[1],S=function(e,t){p((function(n){return(0,u.Z)((0,u.Z)({},n),{},(0,i.Z)({},e,t))})),g.current.resizeColumns([e]),y.current.resizeColumns([e])};return(0,d.jsxs)("div",{style:{display:"flex",flexDirection:"column",width:"100%",height:"100%"},ref:j,children:[(0,d.jsx)(l(),{columnCount:f,height:20,rowCount:1,ref:g,width:k,columnWidth:function(e){return e in C?C[e]:200},rowHeight:function(e){return 20},showScrollbar:!1,itemRenderer:function(e){return(0,d.jsx)(a,(0,u.Z)({onResize:S},e))}}),(0,d.jsx)(l(),{columnCount:f,rowCount:x,height:b-20,width:k,ref:y,columnWidth:function(e){return e in C?C[e]:200},rowHeight:function(e){return 20},onScroll:function(e){var t=e.scrollLeft;g.current.scrollTo({scrollLeft:t})},itemRenderer:function(e){var t=e.rowIndex,i=e.columnIndex,o=e.x,u=e.y,c=e.width,l=e.height,h=e.key,a=n[t][Object.keys(n[0])[i]];return(0,d.jsxs)(r.Fragment,{children:[(0,d.jsx)(s.Rect,{x:o,y:u,height:l,width:c,fill:"white",stroke:"grey",strokeWidth:.5}),(0,d.jsx)(s.Text,{x:o,y:u,height:l,width:c,text:a,fontStyle:"normal",verticalAlign:"middle",align:"center"})]},h)}})]})};var f=function(e){var t="string"===typeof e.data?JSON.parse(e.data):e.data;return(0,d.jsx)(a,{data:t})}}}]);
//# sourceMappingURL=DataFrame.7fa444f4.chunk.js.map