"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[3423],{78244:function(e,t,n){n.d(t,{Z:function(){return f}});var i=n(1413),a=n(29439),s=n(72791),r=n(68286),o=n(78946),l=n(30159),u=n(16551),d=n(80184);var f=function(e){var t=s.useState(1),n=(0,a.Z)(t,2),f=n[0],c=n[1],h=s.useState("hidden"),v=(0,a.Z)(h,2),m=v[0],x=v[1],b=s.useRef(null),y=(0,o.nY)(e).data;function j(){var e=b.current,t=null===e||void 0===e?void 0:e.firstChild,n=null===e||void 0===e?void 0:e.parentElement;if(e&&t&&n){var i=e.offsetWidth+20,a=e.offsetHeight+20,s=n.offsetWidth/i,r=(n.offsetHeight-30)/a;c(s<1||r<1?Math.min(s,r):1)}}function Z(){window.requestAnimationFrame((function(){b.current&&(j(),x("visible"))}))}return s.useEffect((function(){b.current&&e.style&&j()}),[e.style]),(0,d.jsx)(l.Z,{children:(0,d.jsx)("div",{ref:b,style:{display:"inline-block",transform:y?"scale(".concat(f,")"):""},children:y?(0,d.jsx)(r.Z,{style:{visibility:m},data:y.data||[],layout:(0,i.Z)({},y.layout||{}),frames:y.frames,useResizeHandler:!0,onAutoSize:Z,onInitialized:Z,onUpdate:Z}):(0,d.jsx)(u.$j,{size:24,thickness:2})})})}},20725:function(e,t,n){var i=n(72791),a=n(30159),s=n(78244),r=n(80184);function o(e){return(0,r.jsx)(a.Z,{children:(0,r.jsx)(s.Z,{engine:{blobURI:e.engine.blobURI},format:e.data.data.format,name:e.data.sequence.name,context:e.data.sequence.context,step:e.data.record.step,blobData:e.data.data.blobs.data,isFullView:e.isFullView})})}t.Z=i.memo(o)},23331:function(e,t,n){n.r(t),n.d(t,{default:function(){return o}});var i=n(1413),a=(n(72791),n(20725)),s=n(80184);var r=function(e){return(0,s.jsx)("div",{style:{height:"100%",overflow:"hidden",display:"flex",flex:1,alignItems:"center",justifyContent:"center"},children:(0,s.jsx)(a.Z,{data:{data:{data:e.data}},style:{width:"100%",height:"100%"}})})};var o=function(e){return(0,s.jsx)("div",{className:"VizComponentContainer",style:{minHeight:400},children:(0,s.jsx)(r,(0,i.Z)({},e))})}}}]);
//# sourceMappingURL=Plotly.519cb7f3.chunk.js.map