.SplitPane{display:flex;height:100%;width:100%}.SplitPane .gutter{background-color:#fff;transition:all .15s ease-out .2s}.SplitPane.horizontal{flex-direction:row}.SplitPane.horizontal .gutter-horizontal{box-shadow:inset 1px 0 0 0 var(--aim-ui-colors-border30);cursor:col-resize}.SplitPane.horizontal .gutter-horizontal:active,.SplitPane.horizontal .gutter-horizontal:hover{background-color:#89b9f2;box-shadow:none}.SplitPane.horizontal .SplitPaneItem{overflow-x:auto}.SplitPane.vertical{flex-direction:column}.SplitPane.vertical .gutter-vertical{box-shadow:inset 0 2px 0 0 var(--aim-ui-colors-border30);cursor:row-resize}.SplitPane.vertical .gutter-vertical:active,.SplitPane.vertical .gutter-vertical:hover{background-color:#89b9f2;box-shadow:none}.SplitPane.vertical .SplitPaneItem{overflow-y:auto}.SplitPane.hide{visibility:hidden}.ResizingFallback{align-items:center;background-color:#f3f8fe;display:flex;flex-direction:column;height:100%;justify-content:center;text-align:center;-webkit-user-select:none;user-select:none;width:100%}.ResizingFallback__text{padding:.375rem .75rem}.NotificationContainer .MuiAlert-outlinedSuccess{border:.0625rem solid #2bc784}.NotificationContainer .MuiAlert-outlinedError{border:.0625rem solid #e64e48}.NotificationContainer .MuiPaper-root{align-items:center;background:#fff;border-radius:.375rem;display:flex;height:4rem}.NotificationContainer .MuiPaper-root .MuiAlert-icon{padding:0}.NotificationContainer .MuiPaper-root .MuiAlert-icon svg{height:2.375rem;width:2.375rem}.NotificationContainer .MuiPaper-root .MuiAlert-action{align-items:flex-start;display:flex;height:100%}.NotificationContainer .MuiPaper-root .MuiAlert-action .MuiSvgIcon-fontSizeSmall{fill:#1c2852;font-size:1.05rem}.NotificationContainer__contentBox__severity{color:#1c2852;font-size:.875rem;font-weight:550;text-transform:capitalize}.NotificationContainer__contentBox__message{color:#1c2852;font-size:.875rem;font-weight:350}.ResizeElement{display:flex;overflow:scroll;position:relative}.ResizeElement__gutter{display:inline-flex;position:absolute;transition:all .25s cubic-bezier(1,.14,1,.5);z-index:1}.ResizeElement__gutter__left{left:0}.ResizeElement__gutter__left,.ResizeElement__gutter__right{box-shadow:inset 2px 0 0 0 #dceafb;cursor:col-resize;height:100%;top:0}.ResizeElement__gutter__right{right:0}.ResizeElement__gutter__top{box-shadow:inset 0 2px 0 0 #dceafb;cursor:row-resize;left:0;top:0;width:100%}.ResizeElement__gutter__bottom{bottom:0;box-shadow:inset 0 -2px 0 0 #dceafb;cursor:row-resize;left:0;width:100%}.ResizeElement__gutter:active,.ResizeElement__gutter:hover{background-color:#89b9f2;box-shadow:none}.ResizeElement>.ResizableElement{height:100%;width:100%}.Report{height:100vh}.Report__appBar{display:flex;flex:0 1;padding-right:.5rem;white-space:nowrap;width:100%}.Report__title{color:#1473e6;margin:.5em 0;padding:0}.Report__appBar__controls{display:flex}.Report__appBar__controls>*{margin-left:.375rem}.ReportVisualizer{height:calc(100vh - 28px);max-width:100%;overflow:hidden;width:100%}.ReportVisualizer__main{display:flex;height:100%;max-width:100%;overflow:hidden;position:relative;width:100%}.ReportVisualizer__main__editor{background-color:#fff;display:flex;flex-direction:column;height:100%;position:relative}.ReportVisualizer__main__editor .monaco-editor .margin,.ReportVisualizer__main__editor .monaco-editor-background{background-color:#fff}.ReportVisualizer__main__editor__code{flex:.8 1}.ReportVisualizer__main__components{display:flex;flex:1 1;flex-direction:column;overflow:auto;position:relative}.ReportVisualizer__main__components--fullWidth{width:100%}.ReportVisualizer__main__components--loading{align-items:center;justify-content:center}.ReportVisualizer__main__components--processing>:not(.ReportVisualizer__main__components__spinner){-webkit-filter:blur(5px);filter:blur(5px)}.ReportVisualizer__main__components__spinner{align-items:center;display:flex;height:100%;justify-content:center;position:absolute;width:100%;z-index:1}.ReportVisualizer__main__components__viz{display:flex;flex:1 1;flex-direction:column;gap:.75rem;max-width:100%;overflow:auto;padding:1.5rem;position:relative;width:100%}.ReportVisualizer__main__components__viz .Board{height:100%}.ReportVisualizer__main__components__viz__error{color:#e64e48;font-family:Inconsolata,monospace;font-variation-settings:"wdth" 82;padding:.5rem .75rem}
/*# sourceMappingURL=Report.a62c25d1.chunk.css.map*/