"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[1157],{95053:function(t,n,e){e.d(n,{Z:function(){return s}});e(72791);var a=e(78946),i=e(30159),c=e(16551),r=e(80184);var s=function(t){var n=(0,a.sf)(t),e=n.data,s=n.caption;return(0,r.jsx)(i.Z,{children:(0,r.jsx)("div",{style:t.style,children:e.src?(0,r.jsx)("img",{style:{maxHeight:"100%",maxWidth:"100%"},src:e.src,alt:s}):(0,r.jsx)(c.$j,{size:24,thickness:2})})})}},79978:function(t,n,e){e.r(n),e.d(n,{default:function(){return o}});e(72791);var a=e(1413),i=e(95053),c=e(7779),r=e(80184);var s=function(t){var n=t.data.map((function(t){return(0,a.Z)((0,a.Z)((0,a.Z)((0,a.Z)({},t),t.data),t.images),t.record)}));return(0,r.jsx)("div",{className:"ImagesList",style:{height:"100%",overflow:"auto",display:"flex",alignItems:"center",justifyContent:"center",minHeight:40,maxHeight:100},children:n.map((function(t){return(0,r.jsx)(i.Z,{blobData:t.blobs.data,format:t.format,caption:t.caption,name:t.name,context:t.context,step:t.step,index:t.index,engine:{blobURI:c.Z.blobURI}},function(t){var n;return"".concat(null===t||void 0===t||null===(n=t.container)||void 0===n?void 0:n.hash,"_").concat(t.name,"_").concat(JSON.stringify(t.context),"_").concat(t.step,"_").concat(t.index)}(t))}))})};var o=function(t){return(0,r.jsx)(s,{data:t.data})}}}]);
//# sourceMappingURL=Images.7598d414.chunk.js.map