"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[1754],{24977:function(e,i,s){s.r(i);var l=s(72791),n=s(21280),a=s(57678),o=s(40584),t=s(80184);i.default=function(e){var i,s=l.useCallback(n.Z(null===(i=e.callbacks)||void 0===i?void 0:i.on_change,100),[]),u=l.useMemo(o.Z,[]);return(0,t.jsxs)(a.xu,{children:[e.options.label&&(0,t.jsx)(a.xv,{as:"label",htmlFor:u,lineHeight:1.5,disabled:e.options.disabled,children:e.options.label}),(0,t.jsx)(a.iR,{id:u,min:e.options.min,max:e.options.max,value:[e.options.value],step:e.options.step,disabled:e.options.disabled,onValueChange:s})]})}}}]);
//# sourceMappingURL=Slider.9e15c4c1.chunk.js.map