"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[3882],{86250:function(n,o,e){e.r(o);var t=e(29439),i=e(72791),a=e(57678),s=e(80184);o.default=function(n){var o=i.useState("".concat(n.options.value)),e=(0,t.Z)(o,2),l=e[0],c=e[1],u=i.useCallback((function(o){var e;c(o),null===(e=n.callbacks)||void 0===e||e.on_change(o)}),[]),r=i.useMemo((function(){return n.options.options.map((function(n){return"".concat(n)}))}),[n.options.options]);return i.useEffect((function(){n.options.value!==l&&c("".concat(n.options.value))}),[n.options.value]),(0,s.jsxs)(a.xu,{children:[n.options.label&&(0,s.jsx)(a.xv,{as:"label",lineHeight:1.5,disabled:n.options.disabled,children:n.options.label}),(0,s.jsx)(a.Ee,{orientation:n.options.orientation,onValueChange:u,value:l,disabled:n.options.disabled,children:r.map((function(o){return(0,s.jsx)(a.Y8,{id:"".concat(n.component_key,"_").concat(o),value:o,children:(0,s.jsx)(a.xv,{children:o})},o)}))})]})}}}]);
//# sourceMappingURL=Radio.ddf645d5.chunk.js.map