"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[2159],{34647:function(e,t,a){a.r(t);var i=a(1413),n=a(72791),o=a(96728),r=a(97901),s=a(80184);t.default=function(e){var t=n.useMemo((function(){var t,a,n=(null===(t=e.data)||void 0===t||null===(a=t[0])||void 0===a?void 0:a.data.dimensions)||[],o=n.map((function(e){return{type:r._f.Linear,key:e,legend:e,ticksPosition:"before",legendPosition:"start",legendOffset:20}}));return{data:e.data.map((function(e,t){return(0,i.Z)((0,i.Z)({},e.data.values),{},{key:e.key||t})})),variables:o,dimensions:n}}),[e.data]),a=t.data,d=t.variables,l=n.useCallback((function(){var t={data:a,variables:d,margin:{top:50,right:60,bottom:50,left:60},layout:"horizontal",curve:"linear",strokeWidth:2,colors:function(t){var a,i=e.data.find((function(e){return e.key===t.key}));return null!==(a=null===i||void 0===i?void 0:i.color)&&void 0!==a?a:"#000"},theme:{tooltip:{container:{background:"#ffffff",fontSize:12},basic:{},chip:{},table:{},tableCell:{},tableCellValue:{}},axis:{ticks:{line:{stroke:"#dddddd",strokeWidth:1,strokeLinecap:"square"}},domain:{line:{stroke:"#dddddd",strokeWidth:1,strokeLinecap:"square"}}}},legends:[{anchor:"right",direction:"column",justify:!1,translateX:100,translateY:0,itemsSpacing:2,itemWidth:60,itemHeight:20,itemDirection:"left-to-right",itemOpacity:.85,symbolSize:20,effects:[{on:"hover",style:{itemOpacity:1}}]}]};return a.length>600?(0,s.jsx)(o.z0,(0,i.Z)({},t)):(t.layers=["grid","axes","markers","mesh","legends","annotations","nodes"],t.blendMode="darken",(0,s.jsx)(o.Lj,(0,i.Z)({},t)))}),[a,d,e.data]);return(0,s.jsx)("div",{className:"VizComponentContainer",children:(0,s.jsx)(l,{})})}}}]);
//# sourceMappingURL=ParallelPlot.d9820af4.chunk.js.map