"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[7453],{11256:function(e,l,n){n.r(l);var s=n(1413),o=n(29439),a=n(72791),i=n(57678),u=n(40584),t=n(80184);l.default=function(e){var l=a.useState(e.options.value),n=(0,o.Z)(l,2),c=n[0],d=n[1];a.useEffect((function(){e.options.value!==c&&d(e.options.value)}),[e.options.value]);var p=a.useCallback((function(l){var n;d(l),null===(n=e.callbacks)||void 0===n||n.on_change(l)}),[]),r=a.useMemo(u.Z,[]);return(0,t.jsxs)(i.xu,{display:"flex",fd:"column",children:[e.options.label&&(0,t.jsx)(i.xv,{as:"label",htmlFor:r,lineHeight:1.5,disabled:e.options.disabled,children:e.options.label}),(0,t.jsx)(i.rs,(0,s.Z)((0,s.Z)({},e.options),{},{checked:c,onCheckedChange:p}))]})}}}]);
//# sourceMappingURL=Switch.3b262ce0.chunk.js.map