"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[3889],{45495:function(e,t,r){r.r(t),r.d(t,{default:function(){return u}});r(72791);var a=r(1413),n=r(80184);var i=function(e){var t=e.data.map((function(e){return(0,a.Z)((0,a.Z)((0,a.Z)((0,a.Z)({},e),e.data),e.texts),e.record)}));return(0,n.jsx)("div",{className:"TextsList",style:{height:"100%",overflow:"auto",minHeight:40,maxHeight:100},children:t.map((function(e,t){return(0,n.jsx)("div",{style:{margin:"5px",flex:1},children:(0,n.jsx)("pre",{style:{padding:"6px 8px",backgroundColor:"#e8eaee",borderRadius:4,color:e.color},children:e.data})},t)}))})};var u=function(e){return(0,n.jsx)(i,{data:e.data},Date.now())}}}]);
//# sourceMappingURL=Texts.127ccce2.chunk.js.map