"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[9531],{78244:function(t,n,e){e.d(n,{Z:function(){return f}});var i=e(1413),a=e(29439),r=e(72791),o=e(68286),s=e(78946),u=e(30159),c=e(16551),l=e(80184);var f=function(t){var n=r.useState(1),e=(0,a.Z)(n,2),f=e[0],d=e[1],v=r.useState("hidden"),h=(0,a.Z)(v,2),m=h[0],b=h[1],p=r.useRef(null),y=(0,s.nY)(t).data;function Z(){var t=p.current,n=null===t||void 0===t?void 0:t.firstChild,e=null===t||void 0===t?void 0:t.parentElement;if(t&&n&&e){var i=t.offsetWidth+20,a=t.offsetHeight+20,r=e.offsetWidth/i,o=(e.offsetHeight-30)/a;d(r<1||o<1?Math.min(r,o):1)}}function x(){window.requestAnimationFrame((function(){p.current&&(Z(),b("visible"))}))}return r.useEffect((function(){p.current&&t.style&&Z()}),[t.style]),(0,l.jsx)(u.Z,{children:(0,l.jsx)("div",{ref:p,style:{display:"inline-block",transform:y?"scale(".concat(f,")"):""},children:y?(0,l.jsx)(o.Z,{style:{visibility:m},data:y.data||[],layout:(0,i.Z)({},y.layout||{}),frames:y.frames,useResizeHandler:!0,onAutoSize:x,onInitialized:x,onUpdate:x}):(0,l.jsx)(c.$j,{size:24,thickness:2})})})}},34777:function(t,n,e){e.r(n),e.d(n,{default:function(){return u}});e(72791);var i=e(1413),a=e(78244),r=e(7779),o=e(80184);var s=function(t){var n=t.data.map((function(t){return(0,i.Z)((0,i.Z)((0,i.Z)((0,i.Z)({},t),t.data),t.figures),t.record)}));return(0,o.jsx)("div",{className:"FiguresList",style:{overflow:"hidden",display:"flex",alignItems:"center",justifyContent:"center",height:200,width:300},children:n.map((function(t){return(0,o.jsx)(a.Z,{blobData:t.blobs.data,format:t.format,name:t.name,context:t.context,step:t.step,engine:{blobURI:r.Z.blobURI}},function(t){var n;return"".concat(null===t||void 0===t||null===(n=t.container)||void 0===n?void 0:n.hash,"_").concat(t.name,"_").concat(JSON.stringify(t.context),"_").concat(t.step)}(t))}))})};var u=function(t){return(0,o.jsx)(s,{data:t.data},Date.now())}}}]);
//# sourceMappingURL=Figures.99ccea26.chunk.js.map