"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[8866],{82654:function(n,t,a){a.d(t,{Z:function(){return c}});a(72791);var o=a(78946),e=a(30159),i=a(57678),r=a(80184);var c=function(n){var t=(0,o.DR)(n),a=t.audioRef,c=t.data,s=t.setIsPlaying,u=t.setProcessing,d=t.onPlay,l=t.onDownload,f=t.processing,v=t.isPlaying,p=t.readyToPlay,y=t.caption;return(0,r.jsx)(e.Z,{children:(0,r.jsx)("div",{style:n.style,children:(0,r.jsx)(i.zF,{audioRef:a,src:c.src,onEnded:function(){return s(!1)},onCanPlay:function(){return u(!1)},onPlay:d,onPause:function(){return s(!1)},onDownload:l,processing:f,isPlaying:v,readyToPlay:p,caption:y})})})}},21891:function(n,t,a){a.r(t),a.d(t,{default:function(){return s}});var o=a(1413),e=(a(72791),a(82654)),i=a(7779),r=a(80184);var c=function(n){var t=n.data.map((function(n){return(0,o.Z)((0,o.Z)((0,o.Z)((0,o.Z)({},n),n.data),n.audios),n.record)}));return(0,r.jsx)("div",{className:"AudiosList",style:{height:"100%",overflow:"auto"},children:t.map((function(n){return(0,r.jsx)(e.Z,{blobData:n.blobs.data,format:n.format,caption:n.caption,name:n.name,context:n.context,step:n.step,index:n.index,engine:{events:i.Z.events,blobURI:i.Z.blobURI}},function(n){var t;return"".concat(null===n||void 0===n||null===(t=n.container)||void 0===t?void 0:t.hash,"_").concat(n.name,"_").concat(JSON.stringify(n.context),"_").concat(n.step,"_").concat(n.index)}(n))}))})};var s=function(n){return(0,r.jsx)(c,{data:n.data})}}}]);
//# sourceMappingURL=Audios.5b8cc4bb.chunk.js.map