.NotificationContainer .MuiAlert-outlinedSuccess{border:.0625rem solid #2bc784}.NotificationContainer .MuiAlert-outlinedError{border:.0625rem solid #e64e48}.NotificationContainer .MuiPaper-root{align-items:center;background:#fff;border-radius:.375rem;display:flex;height:4rem}.NotificationContainer .MuiPaper-root .MuiAlert-icon{padding:0}.NotificationContainer .MuiPaper-root .MuiAlert-icon svg{height:2.375rem;width:2.375rem}.NotificationContainer .MuiPaper-root .MuiAlert-action{align-items:flex-start;display:flex;height:100%}.NotificationContainer .MuiPaper-root .MuiAlert-action .MuiSvgIcon-fontSizeSmall{fill:#1c2852;font-size:1.05rem}.NotificationContainer__contentBox__severity{color:#1c2852;font-size:.875rem;font-weight:550;text-transform:capitalize}.NotificationContainer__contentBox__message{color:#1c2852;font-size:.875rem;font-weight:350}.ResizingFallback{align-items:center;background-color:#f3f8fe;display:flex;flex-direction:column;height:100%;justify-content:center;text-align:center;-webkit-user-select:none;user-select:none;width:100%}.ResizingFallback__text{padding:.375rem .75rem}.SplitPane{display:flex;height:100%;width:100%}.SplitPane .gutter{background-color:#fff;transition:all .15s ease-out .2s}.SplitPane.horizontal{flex-direction:row}.SplitPane.horizontal .gutter-horizontal{box-shadow:inset 1px 0 0 0 var(--aim-ui-colors-border30);cursor:col-resize}.SplitPane.horizontal .gutter-horizontal:active,.SplitPane.horizontal .gutter-horizontal:hover{background-color:#89b9f2;box-shadow:none}.SplitPane.horizontal .SplitPaneItem{overflow-x:auto}.SplitPane.vertical{flex-direction:column}.SplitPane.vertical .gutter-vertical{box-shadow:inset 0 2px 0 0 var(--aim-ui-colors-border30);cursor:row-resize}.SplitPane.vertical .gutter-vertical:active,.SplitPane.vertical .gutter-vertical:hover{background-color:#89b9f2;box-shadow:none}.SplitPane.vertical .SplitPaneItem{overflow-y:auto}.SplitPane.hide{visibility:hidden}.ResizeElement{display:flex;overflow:scroll;position:relative}.ResizeElement__gutter{display:inline-flex;position:absolute;transition:all .25s cubic-bezier(1,.14,1,.5);z-index:1}.ResizeElement__gutter__left{left:0}.ResizeElement__gutter__left,.ResizeElement__gutter__right{box-shadow:inset 2px 0 0 0 #dceafb;cursor:col-resize;height:100%;top:0}.ResizeElement__gutter__right{right:0}.ResizeElement__gutter__top{box-shadow:inset 0 2px 0 0 #dceafb;cursor:row-resize;left:0;top:0;width:100%}.ResizeElement__gutter__bottom{bottom:0;box-shadow:inset 0 -2px 0 0 #dceafb;cursor:row-resize;left:0;width:100%}.ResizeElement__gutter:active,.ResizeElement__gutter:hover{background-color:#89b9f2;box-shadow:none}.ResizeElement>.ResizableElement{height:100%;width:100%}
/*# sourceMappingURL=App.11696a45.chunk.css.map*/