"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[1150],{78674:function(e,l,a){a.r(l);var n=a(72791),s=a(57678),i=a(40584),o=a(80184);l.default=function(e){var l=n.useCallback((function(l){var a,n=l.target;null===(a=e.callbacks)||void 0===a||a.on_change(n.value)}),[]),a=n.useMemo(i.Z,[]);return(0,o.jsxs)(s.xu,{flex:1,children:[e.options.label&&(0,o.jsx)(s.xv,{as:"label",htmlFor:a,lineHeight:1.5,disabled:e.options.disabled,children:e.options.label}),(0,o.jsx)(s.II,{id:a,value:e.options.value,disabled:e.options.disabled,onChange:l})]})}}}]);
//# sourceMappingURL=TextInput.f5062f21.chunk.js.map