"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[5060],{75616:function(n,a,e){var t=e(93433),o=e(72791),i=e(67571),r=e(94266),u=e(43403),c=e(55779),d=e(16729),l=e(7779),p=e(49379);a.Z=function(){var n,a=(0,i.k6)(),e=(0,i.TH)(),f=(0,d.Z)((function(n){return n.isLoading})),s=(0,d.Z)((function(n){return n.editBoard})),v=(0,d.Z)((function(n){return n.fetchBoard})),Z=(0,d.Z)((function(n){return n.boards})),m=(0,d.Z)((function(n){return n.notifyData})),h=(0,d.Z)((function(n){return n.appName})),g=(0,d.Z)((function(n){return n.setAppName})),N=(0,l.w)(l.Z.boardsSelector),b=h&&null!==(n=null===N||void 0===N?void 0:N[h])&&void 0!==n?n:[],k=o.useMemo((function(){var n=r.Z(b),a=n.filter((function(n){return n.includes("/")})),e=n.filter((function(n){return!n.includes("/")}));return[].concat((0,t.Z)(a),(0,t.Z)(e))}),[b]);return o.useEffect((function(){p.t(u.q.app.pageView)}),[]),o.useEffect((function(){if(!f&&h&&k.length>0&&e.pathname===c.A.App.replace(":appName",h)){var n=k[0];a.replace("".concat(c.A.App.replace(":appName",h),"/").concat(n))}}),[b,e,h]),{data:k,updateBoard:s,boards:Z,isLoading:f,fetchBoard:v,notifications:m,appName:h,setAppName:g}}},65813:function(n,a,e){e.r(a);var t=e(29439),o=e(72791),i=e(16551),r=e(5377),u=e(75616),c=e(80184);a.default=function(n){var a,e,d=(0,u.Z)(),l=d.boards,p=d.isLoading,f=d.fetchBoard,s=d.data,v=d.appName,Z=n.options.package_name,m=n.data.indexOf(":"),h=-1===m?null:n.data.slice(0,m),g=h?n.data:Z&&!s.includes(n.data)?"".concat(Z,":").concat(n.data):"".concat(v,":").concat(n.data),N=o.useState(null!==(a=null===l||void 0===l||null===(e=l[g])||void 0===e?void 0:e.code)&&void 0!==a?a:null),b=(0,t.Z)(N,2),k=b[0],w=b[1];return o.useEffect((function(){var n;null===k&&(null!==l&&void 0!==l&&l.hasOwnProperty(g)?w(null===l||void 0===l||null===(n=l[g])||void 0===n?void 0:n.code):f(g))}),[k,l]),(0,c.jsx)("div",{className:"VizComponentContainer",style:{flex:1,padding:0,border:"none"},children:p||null===k?(0,c.jsx)(i.$j,{}):(0,c.jsx)(r.Z,{data:{code:k,path:g},editMode:!1,previewMode:!0,stateStr:n.options.state_str,externalPackage:h})})}}}]);
//# sourceMappingURL=BoardEmbed.879c686d.chunk.js.map