.StatisticsCard{align-items:center;border:.0625rem solid transparent;border-radius:.25rem;display:inline-flex;justify-content:flex-start;max-width:8.25rem;min-width:8.25rem;padding:.5rem;position:relative;transition:all .18s ease-out}.StatisticsCard__iconWrapper{align-items:center;border-radius:50%;display:inline-flex;height:2rem;justify-content:center;margin-right:.5rem;min-width:2rem;width:2rem}.StatisticsCard__info{display:flex;flex-direction:column;overflow:hidden}.StatisticsCard__info__count,.StatisticsCard__info__label{color:#1c2852;overflow:hidden;text-overflow:ellipsis;-webkit-user-select:none;user-select:none;white-space:nowrap}.StatisticsCard__info__label{text-transform:capitalize}.StatisticsCard__badge{background-color:#fff;border-radius:.125rem;box-shadow:0 1px 2px 0 #00000029;padding:.0625rem .25rem;position:absolute;right:-.375rem;text-align:center;top:-.5rem;-webkit-user-select:none;user-select:none;white-space:nowrap}.StatisticsCard.highlighted{cursor:pointer}.StatisticsBar{background-color:#fafafb;border-radius:.25rem;position:relative}.StatisticsBar__item{display:inline-flex;height:100%;position:absolute;transition:all .18s ease-out}.StatisticsBar__item:first-child{border-bottom-left-radius:.25rem;border-top-left-radius:.25rem}.StatisticsBar__item:last-child{border-bottom-right-radius:.25rem;border-top-right-radius:.25rem}.StatisticsBar__item.highlighted{box-shadow:0 0 0 2px #fff;height:calc(100% + 2px);margin-top:-1px;z-index:1}.ProjectStatistics__totalRuns,.ProjectStatistics__trackedSequences{margin-top:1.5rem}.ProjectStatistics__cards{align-items:center;display:flex;flex-wrap:wrap;gap:1rem;margin-top:.75rem}.ProjectStatistics__bar{margin-top:.75rem}
/*# sourceMappingURL=Explorers.f0c0b4d4.chunk.css.map*/