"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[3804],{10566:function(e,l,a){a.r(l);var o=a(1413),i=a(29439),n=a(72791),s=a(57678),t=a(40584),u=a(80184);l.default=function(e){var l=n.useState(e.options.value),a=(0,i.Z)(l,2),c=a[0],p=a[1];n.useEffect((function(){e.options.value!==c&&p(e.options.value)}),[e.options.value]);var b=n.useCallback((function(l){var a;p(l),null===(a=e.callbacks)||void 0===a||a.on_change(l)}),[]),d=n.useMemo(t.Z,[]);return(0,u.jsxs)(s.xu,{children:[e.options.label&&(0,u.jsx)(s.xv,{as:"label",htmlFor:d,lineHeight:1.5,disabled:e.options.disabled,children:e.options.label}),(0,u.jsx)(s.CO,(0,o.Z)((0,o.Z)({id:d},e.options),{},{leftLabel:e.options.leftValue,rightLabel:e.options.rightValue,disabled:e.options.disabled,value:c,onChange:b}))]})}}}]);
//# sourceMappingURL=ToggleButton.ae6adbfd.chunk.js.map