"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[6798],{13450:function(e,l,a){a.r(l);var n=a(1413),s=a(45987),u=a(72791),i=a(57678),t=a(40584),c=a(80184),o=["label"];l.default=function(e){var l=e.options,a=l.label,r=(0,s.Z)(l,o),b=u.useCallback((function(l){var a,n=l.target;null===(a=e.callbacks)||void 0===a||a.on_change(n.value)}),[]),h=u.useMemo(t.Z,[]);return(0,c.jsxs)(i.xu,{children:[a&&(0,c.jsx)(i.xv,{as:"label",htmlFor:h,lineHeight:1.5,disabled:e.options.disabled,children:a}),(0,c.jsx)(i.gx,(0,n.Z)((0,n.Z)({},r),{},{onChange:b}))]})}}}]);
//# sourceMappingURL=TextArea.f1369385.chunk.js.map