"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[5638],{12963:function(e,o,r){r.d(o,{Z:function(){return p}});var n=r(72791),i=r(16988),t=r(39664),d=r(1413),a=r(25415),c=r(45205);var u=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:"python",o=(0,a.Ik)(),r=n.useRef(null),i=n.useMemo((function(){return(0,c.fB)()}),[]);return n.useEffect((function(){o&&r.current&&(i.theme.config.colors=(0,d.Z)((0,d.Z)({},i.theme.config.colors),{},{"editor.background":"#f2f3f4"}),o.editor.defineTheme(i.theme.name,i.theme.config),o.editor.setTheme(i.theme.name),o.editor.colorizeElement(r.current,{theme:e}))}),[o]),{elementRef:r}},l=r(4942),s=r(47956),g=(0,s.zo)("div",{visibility:"hidden",top:"0.75rem",right:"1rem",display:"inline-block",cursor:"pointer",position:"absolute",ai:"center",jc:"center"}),f=(0,s.zo)("div",{background:"#f2f3f4",br:"$3",p:"$9 3rem $9 $9",position:"relative",minHeight:"3.5rem",display:"flex",ai:"center",overflow:"auto","&:hover":(0,l.Z)({},"".concat(g),{visibility:"visible"})}),h=(0,s.zo)("pre",{margin:0,fontStyle:"normal",fontSize:"$4",lh:"1.3125rem",overflow:"auto",fontMono:15}),m=r(80184);function v(e){var o=e.code,r=void 0===o?"":o,n=e.className,d=void 0===n?"":n,a=e.language,c=void 0===a?"python":a,l=e.hideCopyIcon,s=void 0!==l&&l,v=u(c).elementRef;return(0,m.jsx)(t.Z,{children:(0,m.jsxs)(f,{className:"CodeBlock ".concat(d," "),children:[(0,m.jsx)(h,{as:"pre",className:"ScrollBar__hidden","data-lang":c,ref:v,children:r}),(0,m.jsx)(t.Z,{children:s?null:(0,m.jsx)(g,{children:(0,m.jsx)(i.Z,{contentRef:v})})})]})})}var p=n.memo(v)},45205:function(e,o,r){r.d(o,{Rf:function(){return l},fB:function(){return u}});var n=r(4942),i=r(1413),t=r(38537),d="#fff",a="#414b6d",c="#a1c7f5",u=function(){var e=arguments.length>0&&void 0!==arguments[0]&&arguments[0];return{height:e?"62px":"24px",options:{lineNumbers:"off",minimap:{enabled:!1},fontFamily:'"Inconsolata", monospace',wordWrap:e?"on":"off",fontSize:16,fontWeight:"500",lineNumbersMinChars:0,overviewRulerLanes:0,overviewRulerBorder:!1,lineDecorationsWidth:0,hideCursorInOverviewRuler:!0,contextmenu:!1,glyphMargin:!1,wordBasedSuggestions:!1,folding:!1,scrollBeyondLastColumn:0,renderLineHighlight:"none",scrollbar:{horizontal:"hidden",vertical:"hidden"},find:{addExtraSpaceOnTop:!1,autoFindInSelection:"never",seedSearchStringFromSelection:"never"}},theme:{name:"aim-theme",config:{base:"vs",inherit:!0,rules:[{background:"ffffff"}],colors:{"editor.foreground":a,"editor.background":d,"editorCursor.foreground":"#83899e","dropdown.background":d,"editorSuggestWidget.background":d,"editorSuggestWidget.border":c,"editorSuggestWidget.selectedBackground":"#dceafb","editorSuggestWidget.selectedForeground":a,"editorSuggestWidget.highlightForeground":"#1c2852","editorSuggestWidget.focusHighlightForeground":"#1c2852","editorSuggestWidget.foreground":a,"list.hoverBackground":"#f3f8fe","scrollbar.shadow":d,"editorHoverWidget.background":d,"editorHoverWidget.border":c,"editorHoverWidget.statusBarBackground":d,"editorHoverWidget.foreground":a}}}}},l=((0,i.Z)((0,i.Z)({},u().options),{},{readonly:!0}),function(e,o){var r,d={run:(0,i.Z)({active:!1,hash:"",name:"",experiment:"",tags:"",archived:!1,created_at:0,finalized_at:0,duration:0},(null===o||void 0===o?void 0:o.params)||{})};return(r={},(0,n.Z)(r,t.P.METRICS,d),(0,n.Z)(r,t.P.FIGURES,d),(0,n.Z)(r,t.P.FIGURES3D,d),(0,n.Z)(r,t.P.AUDIOS,d),(0,n.Z)(r,t.P.TEXT,d),r)[e]||d})},39962:function(e,o,r){r.r(o);r(72791);var n=r(57678),i=r(12963),t=r(80184);o.default=function(e){return(0,t.jsx)(n.xu,{children:(0,t.jsx)(i.Z,{code:"".concat(e.data),language:e.options.language})})}}}]);
//# sourceMappingURL=Code.8be35edf.chunk.js.map