.LineChart{background-color:#fff;height:100%;min-height:9.375rem;min-width:9.375rem;overflow:hidden;position:relative;-webkit-user-select:none;user-select:none;width:100%}.LineChart .unableToDrawText{fill:#586069;font-size:.875rem;left:50%;position:absolute;text-align:center;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:80%}.LineChart.backgroundRect{cursor:crosshair}.LineChart.zoomMode rect{cursor:zoom-in}.LineChart .HoverCircle{stroke-width:2.4;fill:#fff;border-radius:50%;cursor:pointer;opacity:1;paint-order:stroke}.LineChart .HoverCircle.focus{stroke-width:4;-webkit-clip-path:initial;clip-path:none}.LineChart .HoverCircle.focus__shadow{stroke-width:12}.LineChart .HoverCircle.active{stroke-width:5}.LineChart .Attributes.highlight .HoverCircle:not(.active):not(.focus){opacity:.5}.LineChart .Attributes.highlight .inProgressLineIndicator:not(.active):not(.focus){opacity:.8}.LineChart .ChartMouseValue{background-color:#f7faff;border:1px solid #7a94cc;box-sizing:border-box;color:#243969;font-size:10px;font-weight:350;padding:.375rem .5rem;position:absolute;white-space:nowrap}.LineChart .ChartMouseValueXAxis{border-radius:0 0 6px 6px;border-top:none;overflow:hidden;-webkit-transform:translateX(-50%);transform:translateX(-50%)}.LineChart .ChartMouseValueYAxis{border-radius:6px 0 0 6px;border-right:none;box-shadow:inset -8px 0 5px -6px #3b5896;overflow:hidden;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.LineChart .Lines{overflow:hidden}@media(-webkit-min-device-pixel-ratio:2),(min-resolution:192dpi){.LineChart .Lines.optimizeRendering{shape-rendering:optimizeSpeed}}.LineChart .Lines.highlight .AggrLine{opacity:.2}.LineChart .Lines.highlight .AggrArea.highlighted,.LineChart .Lines.highlight .AggrLine.highlighted{opacity:1}.LineChart .Lines.highlight>.Line:not(.active):not(.highlighted):not(.aggregated){stroke-width:1.5;opacity:.2}.LineChart .Lines.highlight>.AggrArea:not(.highlighted){opacity:.2}.LineChart .Line{stroke-width:1.5;opacity:1}.LineChart .Line.active{stroke-width:3;opacity:1}.LineChart .Line.highlighted{stroke-width:2.8;opacity:1}.LineChart .Line.aggregated{stroke-width:.4;opacity:0}.LineChart .Line.aggregated.active{stroke-width:3;opacity:.8}.LineChart .Line.aggregated.highlighted{stroke-width:2.8;opacity:.5}.LineChart .AggrLine{stroke-width:2.2;opacity:1}.LineChart .inProgressLineIndicator{-webkit-animation:inProgressIndicator .5s cubic-bezier(.6,-.03,.22,.76) infinite;animation:inProgressIndicator .5s cubic-bezier(.6,-.03,.22,.76) infinite;cursor:pointer;-webkit-filter:drop-shadow(0 0 .5px #fff) drop-shadow(0 0 .5px #fff) drop-shadow(0 0 .5px #fff);filter:drop-shadow(0 0 .5px #ffffff) drop-shadow(0 0 .5px #ffffff) drop-shadow(0 0 .5px #ffffff);opacity:1;paint-order:stroke}@-webkit-keyframes inProgressIndicator{0%{stroke-width:3}50%{stroke-width:5}to{stroke-width:3}}@keyframes inProgressIndicator{0%{stroke-width:3}50%{stroke-width:5}to{stroke-width:3}}
/*# sourceMappingURL=LineChart.bca6567e.chunk.css.map*/