"use strict";(self.webpackChunkui=self.webpackChunkui||[]).push([[436],{2293:function(e,t,i){i.r(t);var n=i(1413),r=i(72791),o=i(19207),a=i(57678),s=i(80184);t.default=function(e){var t=r.useMemo((function(){var t=0;return{data:e.data.map((function(e){return{id:e.name,color:e.color,data:e.data.xValues.map((function(i,n){return t+=+e.data.yValues.length,{x:i,y:e.data.yValues[n]}}))}})),pointsCount:t}}),[e.data]),i=r.useCallback((function(){var e={data:t.data,margin:{top:50,right:90,bottom:50,left:60},xScale:{type:"linear",reverse:!1},yScale:{type:"linear",reverse:!1},colors:function(e){var i,n=t.data.find((function(t){return t.id===e.serieId}));return null!==(i=null===n||void 0===n?void 0:n.color)&&void 0!==i?i:"#000"},tooltip:function(e){var t=e.node;return(0,s.jsxs)(a.xu,{css:{background:"white",br:"$3",padding:"$6 $8",border:"1px solid #ccc"},children:[(0,s.jsx)(a.xv,{weight:"$4",as:"strong",children:t.serieId}),(0,s.jsxs)(a.xu,{css:{padding:"3px 0"},children:[(0,s.jsx)(a.xv,{css:{mr:"$5"},children:"x:"}),(0,s.jsx)(a.xv,{color:t.color,children:t.x})]}),(0,s.jsxs)(a.xu,{css:{padding:"3px 0"},children:[(0,s.jsx)(a.xv,{css:{mr:"$5"},children:"y:"}),(0,s.jsx)(a.xv,{color:t.color,children:t.y})]})]},t.id)},nodeSize:8,axisTop:null,axisRight:null,axisBottom:{tickSize:4,tickPadding:4,tickRotation:0,legendOffset:36,legendPosition:"middle"},axisLeft:{tickSize:4,tickPadding:4,tickRotation:0,legendOffset:-55,legendPosition:"middle"},legends:[{anchor:"top-right",direction:"column",justify:!1,translateX:110,translateY:0,itemsSpacing:0,itemDirection:"left-to-right",itemWidth:80,itemHeight:20,itemOpacity:.75,symbolSize:8,symbolBorderColor:"rgba(0, 0, 0, .5)",effects:[{on:"hover",style:{itemBackground:"rgba(0, 0, 0, .03)",itemOpacity:1}}]}]};return t.pointsCount>600?(0,s.jsx)(o.vZ,(0,n.Z)({},e)):(e.layers=["grid","axes","markers","mesh","legends","annotations","nodes"],e.blendMode="darken",(0,s.jsx)(o.IG,(0,n.Z)({},e)))}),[t]);return(0,s.jsx)("div",{className:"VizComponentContainer",children:(0,s.jsx)(i,{})})}}}]);
//# sourceMappingURL=ScatterPlot.c2d623f4.chunk.js.map