.Illustration{align-items:center;display:flex;flex-direction:column;height:100%;justify-content:center;overflow:auto;width:100%}.Illustration__hidden{display:none}.Illustration__container{height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;overflow:hidden;padding-bottom:7rem}.Illustration__container__content{text-align:center}.Illustration__container__content .qlAnchor{color:#1473e6;margin:0 .25rem;text-decoration:none}.Illustration__container__content .qlAnchor:hover{text-decoration:underline}.Illustration__container__img{text-align:center}.Illustration__container__img>img,.Illustration__container__img>svg{display:block;margin:0 auto}.Illustration__container__img__small{padding:.5rem}.Illustration__container__img__small>img,.Illustration__container__img__small>svg{height:auto;width:3rem}.Illustration__container__img__medium{padding:.75rem}.Illustration__container__img__medium>img,.Illustration__container__img__medium>svg{height:auto;width:7.5rem}.Illustration__container__img__large{padding:.75rem}.Illustration__container__img__large>img,.Illustration__container__img__large>svg{height:auto;width:14.5rem}.Illustration__container__img__xLarge{padding:1rem}.Illustration__container__img__xLarge>img,.Illustration__container__img__xLarge>svg{height:auto;width:19.5rem}
/*# sourceMappingURL=Apps.b0ad9aab.chunk.css.map*/